==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebCancelableBrowserEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDescriptionMetadata } from "./WebCancelableEventArgsDescriptionMetadata";
import { WebCancelableBrowserEventArgsDescription } from "./WebCancelableBrowserEventArgsDescription";
/**
 * @hidden
 */
var WebCancelableBrowserEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCancelableBrowserEventArgsDescriptionMetadata, _super);
    function WebCancelableBrowserEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCancelableBrowserEventArgsDescriptionMetadata.b = function (a) {
        if (WebCancelableBrowserEventArgsDescriptionMetadata.a == null) {
            WebCancelableBrowserEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCancelableBrowserEventArgsDescriptionMetadata.c(WebCancelableBrowserEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebCancelableBrowserEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCancelableBrowserEventArgsDescriptionMetadata.a);
    };
    WebCancelableBrowserEventArgsDescriptionMetadata.c = function (a) {
        WebCancelableEventArgsDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:CancelableBrowserEventArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebCancelableBrowserEventArgsDescriptionMetadata.d = function (a) {
        WebCancelableBrowserEventArgsDescriptionMetadata.b(a);
        a.aa("WebCancelableBrowserEventArgs", function () { return new WebCancelableBrowserEventArgsDescription(); });
        a.z("WebCancelableBrowserEventArgs", WebCancelableBrowserEventArgsDescriptionMetadata.a);
    };
    WebCancelableBrowserEventArgsDescriptionMetadata.$t = markType(WebCancelableBrowserEventArgsDescriptionMetadata, 'WebCancelableBrowserEventArgsDescriptionMetadata');
    WebCancelableBrowserEventArgsDescriptionMetadata.a = null;
    return WebCancelableBrowserEventArgsDescriptionMetadata;
}(Base));
export { WebCancelableBrowserEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebCancelableBrowserEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDescriptionMetadata } from "./WebCancelableEventArgsDescriptionMetadata";
import { WebCancelableBrowserEventArgsDescription } from "./WebCancelableBrowserEventArgsDescription";
/**
 * @hidden
 */
var WebCancelableBrowserEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCancelableBrowserEventArgsDescriptionMetadata, _super);
    function WebCancelableBrowserEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCancelableBrowserEventArgsDescriptionMetadata.b = function (a) {
        if (WebCancelableBrowserEventArgsDescriptionMetadata.a == null) {
            WebCancelableBrowserEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCancelableBrowserEventArgsDescriptionMetadata.c(WebCancelableBrowserEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebCancelableBrowserEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebCancelableBrowserEventArgsDescriptionMetadata.a);
    };
    WebCancelableBrowserEventArgsDescriptionMetadata.c = function (a) {
        WebCancelableEventArgsDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:CancelableBrowserEventArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebCancelableBrowserEventArgsDescriptionMetadata.d = function (a) {
        WebCancelableBrowserEventArgsDescriptionMetadata.b(a);
        a.ac("WebCancelableBrowserEventArgs", function () { return new WebCancelableBrowserEventArgsDescription(); });
        a.ab("WebCancelableBrowserEventArgs", WebCancelableBrowserEventArgsDescriptionMetadata.a);
    };
    WebCancelableBrowserEventArgsDescriptionMetadata.$t = markType(WebCancelableBrowserEventArgsDescriptionMetadata, 'WebCancelableBrowserEventArgsDescriptionMetadata');
    WebCancelableBrowserEventArgsDescriptionMetadata.a = null;
    return WebCancelableBrowserEventArgsDescriptionMetadata;
}(Base));
export { WebCancelableBrowserEventArgsDescriptionMetadata };
